library cookie;
import 'dart:io';

/**
 * This is largely lifted from dart:io code so we can use it in shelf
 * todo: Replace this with wahatever cookie code comes in shelf.
 * See [https://code.google.com/p/dart/issues/detail?id=18845]
 *
 */

Map<String,Cookie> parseCookies(Map<String,String> headers) {
    // Parse a Cookie header value according to the rules in RFC 6265.
    var cookies = new Map<String,Cookie>();

    void parseCookieString(String s) {
      int index = 0;

      bool done() => index == -1 || index == s.length;

      void skipWS() {
        while (!done()) {
         if (s[index] != " " && s[index] != "\t") return;
         index++;
        }
      }

      String parseName() {
        int start = index;
        while (!done()) {
          if (s[index] == " " || s[index] == "\t" || s[index] == "=") break;
          index++;
        }
        return s.substring(start, index);
      }

      String parseValue() {
        int start = index;
        while (!done()) {
          if (s[index] == " " || s[index] == "\t" || s[index] == ";") break;
          index++;
        }
        return s.substring(start, index);
      }

      bool expect(String expected) {
        if (done()) return false;
        if (s[index] != expected) return false;
        index++;
        return true;
      }

      while (!done()) {
        skipWS();
        if (done()) return;
        String name = parseName();
        skipWS();
        if (!expect("=")) {
          index = s.indexOf(';', index);
          continue;
        }
        skipWS();
        String value = parseValue();
        try {
          cookies[name] = new Cookie(name, value);
        } catch (_) {
          // Skip it, invalid cookie data.
        }
        skipWS();
        if (done()) return;
        if (!expect(";")) {
          index = s.indexOf(';', index);
          continue;
        }
      }
    }

    var c = headers[HttpHeaders.COOKIE];
    if( c != null )
      parseCookieString(c);

    return cookies;
  }
